@@ -71,7 +71,9 @@ class ObjectFieldLabel(hg.ContextValue):
         object = hg.resolve_lazy(object, context)
         label = resolve_modellookup(object._meta.model, self.fieldname)[-1]
         label = getattr(
-            object.objects.get_queryset().query.annotations.get(self.fieldname, None),
+            object._meta.model.objects.get_queryset().query.annotations.get(
+                self.fieldname, None
+            ),
             "output_field",
             label,
         )  # test for annotated ("dynamic") fields
